# Development Scripts

* `scripts/setup` - Install dependencies.
* `scripts/test` - Run the test suite.
* `scripts/lint` - Run the code format.
* `scripts/check` - Run the lint in check mode, and the type checker.

Styled after GitHub's ["Scripts to Rule Them All"](https://github.com/github/scripts-to-rule-them-all).
